/* ============================================================================
 * File Name: DDS_sw_01a_dev
 *   DDS_sw v0.0 custom component
 *
 * Description:
 *   Implements software DDS to generate sine, ramp and triangle waves
 *   Output data types:
 *      int8, int16, int32, uint8, uint16, uin32, float
 *
 *
 * Credits:
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/


#ifndef `$INSTANCE_NAME`_H
#define `$INSTANCE_NAME`_H
 
    
#include <project.h>
#include <cytypes.h>
           
#define true  1
#define false 0

/***************************************
*        read-only parameters
***************************************/  

#define `$INSTANCE_NAME`_DataType                   `=$DataType `  // Output data type: int8(uint8), int16(uint16), int32(uint32) and float.  
#define `$INSTANCE_NAME`_PresetClockFreq (double)   `=$ClockFreq`  // preset sampling clock frequency
#define `$INSTANCE_NAME`_PresetFreq (double)        `=$Frequency`  // preset startup frequency 
#define `$INSTANCE_NAME`_PresetAmpl                 `=$Amplitude`  // preset startup wave amplitude 
#define `$INSTANCE_NAME`_Algorithm                  `=$Algorithm`  // method 



    
/***************************************
*        global variables
***************************************/  
    
    

//#define DDS_RESOLUTION (double) 4294967296.0 // 4294967296 = 2^32
//#define TUNE_WORD_MAX  (uint32) 2147483647   // 2147483647 = 2^32 - 1 = DDS_RESOLUTION/2 - 1

//uint32 dds_acc; // DDS accumulator
//uint32 dds_inc; // DDS tune word inctrement 


`=$data_t` `$INSTANCE_NAME`_sin;
`=$data_t` `$INSTANCE_NAME`_cos;
uint32     `$INSTANCE_NAME`_phase;
int32      `$INSTANCE_NAME`_ref; // todo: int?

    
    


/***************************************
*        read-only variables
***************************************/  

#define `$INSTANCE_NAME`_Frequency  `$INSTANCE_NAME`_GetFrequency()     // return current set frequency
#define `$INSTANCE_NAME`_Clock      `$INSTANCE_NAME`_GetClock()         // return current sampling clock frequency
#define `$INSTANCE_NAME`_Amplitude  `$INSTANCE_NAME`_GetAmplitude()     // return current amplitude
#define `$INSTANCE_NAME`_OutpFreq   `$INSTANCE_NAME`_GetOutFreq()       // read actual output frequency
#define `$INSTANCE_NAME`_Enabled    `$INSTANCE_NAME`_GetEnable()        // read enabled status

 
    
/***************************************
*        Function Prototypes
***************************************/

`$data_t` `$INSTANCE_NAME`_GetSample(uint8 nextval);
void    `$INSTANCE_NAME`_Start();
void    `$INSTANCE_NAME`_Stop();
void    `$INSTANCE_NAME`_Enable();
void    `$INSTANCE_NAME`_Reset();                       // reset DDS accumulator
uint8   `$INSTANCE_NAME`_SetFrequency( double freq );
uint8   `$INSTANCE_NAME`_SetClock( double freq );
void    `$INSTANCE_NAME`_SetAmplitude( int32 value );


//void  DDS_FillBuffer(uint16 start, uint16 length );
//void  DDS_FillHalfBuffer(); 

int32   `$INSTANCE_NAME`_GetAmplitude();                // return current amplitude 
double  `$INSTANCE_NAME`_GetFrequency();                // return current set frequency 
double  `$INSTANCE_NAME`_GetOutpFreq();                 // read actual output frequency
double  `$INSTANCE_NAME`_GetClock();                    // return current sampling frequency 
uint32  `$INSTANCE_NAME`_CalcStep( double Freq );       // Calculate TuneWord from frequency
uint8   `$INSTANCE_NAME`_GetEnable();                   // Software Enable status


    
#endif /* `$INSTANCE_NAME`_H */


/* [] END OF FILE */
