/* ============================================================================
 * Project Name: DMA_3phase_VDAC_01b_basic
 *
 * Description:
 *   PSoC5 demo showing 3-phase analog sine output generator
 *   with variable frequency and amplitude.
 *   Project uses DMA to transfer sine data from RAM buffer to VDAC_1, 2, 3
 *   to produce 120-degree shifted sine voltage.
 *
 *   Frequency - 5kHz fixed 
 *   Amplitude - [0V to 4V p-p], resolution 8-bit
 *    
 *   Amplitude adjustment achived by re-calculating RAM Buffer values
 *
 * Uses:
 *   project uses custom component:
 *   DDS_sw 0.0_beta (included in the project), which is simple calculator of the
 *   sine wave to pre-fill the RAM Buffer
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/

#include <project.h>
#include <WaveGen.h>


//===========================================
// Global variables
//===========================================

//===========================================
// Forward declarations
//===========================================


void Initialize()
{
    CyGlobalIntEnable;

    WaveTable_1_SetClock(WaveGen_NumSamples); // WaveGen_NumSamples defined in WaveGen.h
    WaveTable_1_SetAmplitude(255);            // Set sine aamplitude [0-255] <-> [0V-4V]  
    WaveTable_1_Start();

    WaveGen_Start();                          // start wave generator and fill Buffer with default values

    Opamp_1_Start();                      
    Opamp_2_Start();                      
    Opamp_3_Start();                      
    
    VDAC_1_Start();                      
    VDAC_2_Start();                      
    VDAC_3_Start();   
}

int main(void)
{
    
    Initialize();
    

    for(;;) //forever
    {
        // your code here...
    }
    
}




/* [] END OF FILE */

